
.. currentmodule:: tango

.. _testing:

=======================
Testing PyTango Devices
=======================

.. automodule:: tango.test_context

.. toctree::
    :maxdepth: 1

    testing/testing_approaches
    testing/test_context
    testing/mocks
